@@ -3,6 +3,7 @@ use std::io::{Write, Result};
 
 use crate::{Cast, Endian, Flip};
 use crate::experimental::AsBytes;
+#[allow(unused_imports)] use crate::BE; // used in document comment.
 
 
 ///
@@ -16,7 +17,7 @@ use crate::experimental::AsBytes;
 /// # Example
 ///
 /// In the example below, method `decastf` encodes the value in
-/// `udp_hdr1` of type `UdpHdr` to bytes in Big-Endian (`BE`) and
+/// `udp_hdr1` of type `UdpHdr` to bytes in Big-Endian ([`BE`]) and
 /// stores them in `bytes2`.
 ///
 /// ```
@@ -37,17 +38,19 @@ use crate::experimental::AsBytes;
 ///
 /// // Input data: UDP header (8 bytes)
 /// let udp_hdr1 = UdpHdr { sport: 50121, dport: 53, len: 50, sum: 0x823F };
-/// let bytes1: [u8; 8] = [0xC3, 0xC9, 0x00, 0x35, 0x00, 0x32, 0x82, 0x3F];
 ///
-/// // Encode UDP header `udp_hdr2` to bytes in `output2`.
+/// // Encode UDP header `udp_hdr1` to bytes in `output2`.
 /// // Because the UDP header is 8 bytes as defined above,
 /// // only the first 8 bytes of `output2` are filled with data.
 /// let mut output2 = Cursor::new(vec![0_u8; 16]);
 /// output2.decastf(&udp_hdr1, BE)?;
 /// let bytes2 = output2.into_inner();
 ///
+/// // `udp_hdr1` should be encoded as following (8 bytes)
+/// let bytes3: [u8; 8] = [0xC3, 0xC9, 0x00, 0x35, 0x00, 0x32, 0x82, 0x3F];
+///
 /// // Check the results.
-/// assert_eq!(&bytes2[0..8], &bytes1[0..8]);
+/// assert_eq!(&bytes2[0..8], &bytes3[0..8]);
 /// assert_eq!(&bytes2[8..16], &[0_u8; 8]);
 /// # Ok(())
 /// # }
@@ -55,8 +58,8 @@ use crate::experimental::AsBytes;
 ///
 /// # Description
 ///
-/// All methods in this trait `decast` one or more variables to a
-/// number of bytes and writes to I/O.  The type of the value(s) can
+/// All methods in trait `DecastIO` `decast` one or more variables to
+/// a number of bytes and writes to I/O.  The type of the value(s) can
 /// be explicitly specified as the generic type parameter of its
 /// method or simply omitted because the Rust compiler can infer from
 /// the argument.  The endianness of resulting value(s) is flipped
@@ -64,14 +67,14 @@ use crate::experimental::AsBytes;
 /// for trait `Write` is provided.
 ///
 /// The output `self` should have enough room to encode to the
-/// specified number of value(s) of type `T`.  If there is enough
-/// room, the specified variable(s) is/are encoded to bytes and
-/// written to output `self`.  If successful, the size of written
+/// specified number of value(s) of the specified type `T`.  If there
+/// is enough room, the specified variable(s) is/are encoded to bytes
+/// and written to output `self`.  If successful, the size of written
 /// bytes are returned in `Ok`().  If I/O error is detected,
 /// `Err`(std::io::Error) is returned.
 ///
-/// When `endian` is specified, the endianness of resulting bytes is
-/// flipped if necessary.
+/// When argument `endian` is specified, the endianness of resulting
+/// bytes is flipped if necessary.
 ///
 pub trait DecastIO {
     /// Encodes the value pointed by `val_ptr` of type `T` to bytes
