@@ -1,6 +1,7 @@
 use core::{mem, ptr};
 
 use crate::{Cast, Endian, Flip};
+#[allow(unused_imports)] use crate::BE; // used in document comment.
 
 
 ///
@@ -14,7 +15,7 @@ use crate::{Cast, Endian, Flip};
 /// # Example
 ///
 /// In the example below, method `encastf` decodes bytes in `bytes1`
-/// in Big-Endian (`BE`) to variable `udp_hdr2` of type `UdpHdr`.
+/// in Big-Endian ([`BE`]) to variable `udp_hdr2` of type `UdpHdr`.
 ///
 /// ```
 /// # fn main() { test(); }
@@ -50,23 +51,23 @@ use crate::{Cast, Endian, Flip};
 ///
 /// # Description
 ///
-/// All methods in this trait `encast` a number of bytes on memory to
-/// one or more values of the specified type.  The type of the
-/// value(s) can be explicitly specified as the generic type parameter
-/// of the methods or implicitly specified so that the Rust compiler
-/// can infer.  The endianness of resulting value(s) is flipped when
-/// required and necessary.  Currently, only an implementation for
-/// `[u8]` is provided.
+/// All methods in trait `EncastMem` `encast` a number of bytes on
+/// memory to one or more values of the specified type.  The type of
+/// the value(s) can be explicitly specified as the generic type
+/// parameter of the methods or implicitly specified so that the Rust
+/// compiler can infer.  The endianness of resulting value(s) is
+/// flipped when required and necessary.  Currently, only an
+/// implementation for `[u8]` is provided.
 ///
 /// The size of `self` should be larger than or equal to the specified
-/// number of value(s) of type `T`.  If there are enough bytes, the
-/// required number of bytes at the head of `self` are decoded to the
-/// specified type of value(s), which is/are returned in `Some`().
-/// The remaining bytes are ignored.  If there are not enough bytes,
-/// `None` is returned.
+/// number of value(s) of the specified type `T`.  If there are enough
+/// bytes, the required number of bytes at the head of `self` are
+/// decoded to the specified type of value(s), which is/are returned
+/// in `Some`().  The remaining bytes are ignored.  If there are not
+/// enough bytes, `None` is returned.
 ///
-/// When `endian` is specified, the endianness of value(s) is flipped
-/// if necessary.
+/// When argument `endian` is specified, the endianness of value(s) is
+/// flipped if necessary.
 ///
 pub trait EncastMem {
     /// Decodes the bytes at the head of `self` to a value of type `T`.
